define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "MMMM y",
	"field-thu-narrow-relative+0": "questo gio.",
	"field-thu-narrow-relative+1": "gio. prossimo",
	"field-sun-narrow-relative+0": "questa dom.",
	"field-sun-narrow-relative+1": "dom. prossima",
	"months-format-wide": [
		"gennaio",
		"febbraio",
		"marzo",
		"aprile",
		"maggio",
		"giugno",
		"luglio",
		"agosto",
		"settembre",
		"ottobre",
		"novembre",
		"dicembre"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "questo ven.",
	"field-fri-narrow-relative+1": "ven. prossimo",
	"eraNarrow": [
		"aC",
		"dC"
	],
	"dateFormatItem-Hmv": "HH:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d MMM y",
	"dayPeriods-format-abbr-night1": "di notte",
	"dayPeriods-format-narrow-evening1": "di sera",
	"days-standAlone-narrow": [
		"D",
		"L",
		"M",
		"M",
		"G",
		"V",
		"S"
	],
	"days-standAlone-wide": [
		"domenica",
		"lunedì",
		"martedì",
		"mercoledì",
		"giovedì",
		"venerdì",
		"sabato"
	],
	"dayPeriods-format-abbr-afternoon1": "di pomeriggio",
	"dayPeriods-format-wide-evening1": "di sera",
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "mer. scorso",
	"dayPeriods-standAlone-wide-evening1": "sera",
	"days-format-wide": [
		"domenica",
		"lunedì",
		"martedì",
		"mercoledì",
		"giovedì",
		"venerdì",
		"sabato"
	],
	"field-month-short-relative+0": "questo mese",
	"field-month-short-relative+1": "mese prossimo",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "sera",
	"dayPeriods-standAlone-abbr-afternoon1": "pomeriggio",
	"field-thu-relative+0": "questo giovedì",
	"dayPeriods-standAlone-abbr-night1": "notte",
	"field-thu-relative+1": "giovedì prossimo",
	"dayPeriods-format-wide-am": "AM",
	"field-fri-relative+0": "questo venerdì",
	"field-fri-relative+1": "venerdì prossimo",
	"dateFormatItem-yMd": "d/M/y",
	"field-thu-narrow-relative+-1": "gio. scorso",
	"field-quarter-relative+0": "questo trimestre",
	"field-quarter-relative+1": "trimestre prossimo",
	"field-sun-short-relative+0": "questa dom.",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "dom. prossima",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "di pomeriggio",
	"dateFormatItem-Md": "d/M",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "sett.",
	"field-hour-relative+0": "quest’ora",
	"field-day-relative+-1": "ieri",
	"field-day-relative+-2": "l’altro ieri",
	"field-mon-narrow-relative+-1": "lun. scorso",
	"field-minute-narrow": "min",
	"field-thu-short-relative+0": "questo gio.",
	"field-mon-relative+0": "questo lunedì",
	"field-thu-short-relative+1": "gio. prossimo",
	"field-mon-relative+1": "lunedì prossimo",
	"field-day-narrow-relative+0": "oggi",
	"field-era-short": "era",
	"field-day-narrow-relative+1": "domani",
	"field-sat-narrow-relative+0": "questo sab.",
	"field-day-narrow-relative+2": "dopodomani",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "sab. prossimo",
	"field-week-narrow-relative+0": "questa sett.",
	"field-week-narrow-relative+1": "sett. prossima",
	"field-wed-narrow-relative+0": "questo mer.",
	"field-wed-narrow-relative+1": "mer. prossimo",
	"field-month": "mese",
	"months-standAlone-wide": [
		"gennaio",
		"febbraio",
		"marzo",
		"aprile",
		"maggio",
		"giugno",
		"luglio",
		"agosto",
		"settembre",
		"ottobre",
		"novembre",
		"dicembre"
	],
	"field-weekday-narrow": "giorno sett.",
	"dayPeriods-standAlone-narrow-afternoon1": "pomeriggio",
	"field-year-relative+0": "quest’anno",
	"field-year-relative+1": "anno prossimo",
	"dayPeriods-format-abbr-evening1": "di sera",
	"dayPeriods-format-abbr-noon": "mezzogiorno",
	"dayPeriods-format-narrow-midnight": "mezzanotte",
	"dayPeriods-format-wide-midnight": "mezzanotte",
	"field-tue-relative+0": "questo martedì",
	"field-tue-relative+1": "martedì prossimo",
	"dayPeriods-standAlone-abbr-evening1": "sera",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "mezzanotte",
	"field-year-narrow": "anno",
	"dayPeriods-standAlone-abbr-noon": "mezzogiorno",
	"field-tue-short-relative+0": "questo mar.",
	"dayPeriods-standAlone-narrow-midnight": "mezzanotte",
	"field-tue-short-relative+1": "mar. prossimo",
	"field-tue-narrow-relative+0": "questo mar.",
	"field-tue-narrow-relative+1": "mar. prossimo",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "questo mercoledì",
	"field-wed-relative+1": "mercoledì prossimo",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "questo mer.",
	"field-fri-short-relative+0": "questo ven.",
	"field-wed-short-relative+1": "mer. prossimo",
	"field-fri-short-relative+1": "ven. prossimo",
	"field-weekOfMonth-short": "sett. mese",
	"field-quarter-short-relative+-1": "trim. scorso",
	"field-year-short-relative+-1": "anno scorso",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "di notte",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "trim. scorso",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"field-weekOfMonth-narrow": "sett. mese",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "questo minuto",
	"field-year-short-relative+0": "quest’anno",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "anno prossimo",
	"field-weekday": "giorno della settimana",
	"dayPeriods-format-narrow-pm": "p.",
	"field-tue-narrow-relative+-1": "mar. scorso",
	"dateFormatItem-yMEd": "E d/M/y",
	"dayPeriods-standAlone-wide-night1": "notte",
	"field-year-narrow-relative+-1": "anno scorso",
	"field-sat-relative+-1": "sabato scorso",
	"dayPeriods-format-abbr-midnight": "mezzanotte",
	"dayPeriods-format-narrow-morning1": "di mattina",
	"dayPeriods-format-wide-morning1": "di mattina",
	"dayPeriods-standAlone-abbr-midnight": "mezzanotte",
	"dayPeriods-standAlone-narrow-pm": "p.",
	"dayPeriods-standAlone-wide-morning1": "mattina",
	"field-mon-narrow-relative+0": "questo lun.",
	"field-mon-narrow-relative+1": "lun. prossimo",
	"field-second": "secondo",
	"dateFormatItem-yMMMEd": "E d MMM y",
	"field-year-relative+-1": "anno scorso",
	"field-weekdayOfMonth-short": "giorno mese",
	"dateFormat-short": "dd/MM/yy",
	"eraNames": [
		"avanti Cristo",
		"dopo Cristo"
	],
	"field-second-short": "s",
	"field-thu-short-relative+-1": "gio. scorso",
	"field-zone": "fuso orario",
	"field-dayperiod-narrow": "AM/PM",
	"field-sun-short-relative+-1": "dom. scorsa",
	"dayPeriods-standAlone-narrow-morning1": "mattina",
	"eraAbbr": [
		"a.C.",
		"d.C."
	],
	"field-week-short": "sett.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "oggi",
	"field-day-relative+1": "domani",
	"field-day-relative+2": "dopodomani",
	"field-day-short-relative+0": "oggi",
	"field-dayOfYear-short": "giorno anno",
	"field-day-short-relative+1": "domani",
	"dateFormat-long": "d MMMM y",
	"field-day-short-relative+2": "dopodomani",
	"field-sun-narrow-relative+-1": "dom. scorsa",
	"dayPeriods-format-wide-noon": "mezzogiorno",
	"field-second-relative+0": "ora",
	"field-quarter-relative+-1": "trimestre scorso",
	"dayPeriods-format-narrow-night1": "di notte",
	"quarters-format-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dayPeriods-standAlone-wide-noon": "mezzogiorno",
	"dayPeriods-standAlone-narrow-night1": "notte",
	"field-week-relative+-1": "settimana scorsa",
	"dayPeriods-format-abbr-morning1": "di mattina",
	"field-month-relative+-1": "mese scorso",
	"months-format-narrow": [
		"G",
		"F",
		"M",
		"A",
		"M",
		"G",
		"L",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"field-year": "anno",
	"field-era": "era",
	"dayPeriods-standAlone-abbr-morning1": "mattina",
	"days-standAlone-short": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-1": "ieri",
	"field-day-short-relative+-2": "l’altro ieri",
	"dateFormatItem-GyMMM": "MMM y G",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "ora",
	"field-dayOfYear-narrow": "giorno anno",
	"field-quarter": "trimestre",
	"field-month-narrow-relative+0": "questo mese",
	"field-month-narrow-relative+1": "mese prossimo",
	"field-day": "giorno",
	"field-mon-relative+-1": "lunedì scorso",
	"field-dayOfYear": "giorno dell’anno",
	"dateFormat-medium": "d MMM y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-yMMM": "MMM y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormatItem-MEd": "E d/M",
	"field-tue-short-relative+-1": "mar. scorso",
	"field-year-short": "anno",
	"field-month-short": "mese",
	"dateFormatItem-MMMEd": "E d MMM",
	"dayPeriods-format-wide-afternoon1": "del pomeriggio",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"gen",
		"feb",
		"mar",
		"apr",
		"mag",
		"giu",
		"lug",
		"ago",
		"set",
		"ott",
		"nov",
		"dic"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "questo sabato",
	"field-sat-relative+1": "sabato prossimo",
	"dayPeriods-format-wide-pm": "PM",
	"days-standAlone-abbr": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"field-zone-short": "fuso",
	"field-week-short-relative+0": "questa sett.",
	"field-week-short-relative+1": "sett. prossima",
	"dayPeriods-standAlone-wide-afternoon1": "pomeriggio",
	"field-fri-short-relative+-1": "ven. scorso",
	"field-month-narrow": "mese",
	"dayPeriods-format-narrow-am": "m.",
	"field-month-narrow-relative+-1": "mese scorso",
	"days-format-abbr": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"field-weekday-short": "giorno settimana",
	"field-day-narrow-relative+-1": "ieri",
	"field-day-narrow-relative+-2": "l’altro ieri",
	"field-quarter-short": "trim.",
	"days-format-short": [
		"dom",
		"lun",
		"mar",
		"mer",
		"gio",
		"ven",
		"sab"
	],
	"months-standAlone-narrow": [
		"G",
		"F",
		"M",
		"A",
		"M",
		"G",
		"L",
		"A",
		"S",
		"O",
		"N",
		"D"
	],
	"days-format-narrow": [
		"D",
		"L",
		"M",
		"M",
		"G",
		"V",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "trim.",
	"field-mon-short-relative+0": "questo lun.",
	"field-mon-short-relative+1": "lun. prossimo",
	"field-dayperiod-short": "AM/PM",
	"dayPeriods-standAlone-narrow-am": "m.",
	"field-week-narrow-relative+-1": "sett. scorsa",
	"field-thu-relative+-1": "giovedì scorso",
	"field-fri-narrow-relative+-1": "ven. scorso",
	"field-mon-short-relative+-1": "lun. scorso",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "questo trim.",
	"field-quarter-short-relative+1": "trim. prossimo",
	"dateFormatItem-Ed": "E d",
	"field-wed-relative+-1": "mercoledì scorso",
	"field-weekOfMonth": "settimana del mese",
	"field-weekdayOfMonth-narrow": "giorno mese",
	"dayPeriods-standAlone-wide-am": "AM",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "venerdì scorso",
	"field-minute": "minuto",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"1º trimestre",
		"2º trimestre",
		"3º trimestre",
		"4º trimestre"
	],
	"field-day-short": "g.",
	"field-dayperiod": "AM/PM",
	"field-hour-short": "h",
	"months-standAlone-abbr": [
		"gen",
		"feb",
		"mar",
		"apr",
		"mag",
		"giu",
		"lug",
		"ago",
		"set",
		"ott",
		"nov",
		"dic"
	],
	"field-month-relative+0": "questo mese",
	"field-second-narrow": "s",
	"field-month-relative+1": "mese prossimo",
	"dateFormat-full": "EEEE d MMMM y",
	"field-era-narrow": "era",
	"field-sat-short-relative+-1": "sab. scorso",
	"dayPeriods-format-narrow-noon": "mezzogiorno",
	"field-week-short-relative+-1": "sett. scorsa",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-yM": "M/y",
	"field-sun-relative+-1": "domenica scorsa",
	"field-wed-short-relative+-1": "mer. scorso",
	"field-weekdayOfMonth": "giorno del mese",
	"field-quarter-narrow-relative+0": "questo trim.",
	"dateFormatItem-GyMMMEd": "E d MMM y G",
	"field-quarter-narrow-relative+1": "trim. prossimo",
	"field-sat-short-relative+0": "questo sab.",
	"field-hour-narrow": "h",
	"field-sat-short-relative+1": "sab. prossimo",
	"field-year-narrow-relative+0": "quest’anno",
	"field-year-narrow-relative+1": "anno prossimo",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "fuso",
	"dayPeriods-standAlone-narrow-noon": "mezzogiorno",
	"field-tue-relative+-1": "martedì scorso",
	"field-minute-short": "min",
	"dateFormatItem-yw": "'settimana' w 'del' Y",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "questa settimana",
	"field-week-relative+1": "settimana prossima",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "questa domenica",
	"field-sun-relative+1": "domenica prossima",
	"field-sat-narrow-relative+-1": "sab. scorso",
	"quarters-standAlone-abbr": [
		"T1",
		"T2",
		"T3",
		"T4"
	],
	"dateFormatItem-MMMMW": "'settimana' W 'di' MMMM",
	"field-month-short-relative+-1": "mese scorso",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-week": "settimana",
	"field-day-narrow": "g."
}
//end v1.x content
);